=====
mldoe
=====

..
    - License
    - Python version
    - PyPi version
    - Requirements up-to-date (https://www.requires.io)
    - Documentation status
    - % Code cover (https://www.coveralls.io)
    - CI (https://www.travis-ci.org)

This package provides the tools to create and characterize regular mixed-level designs (with four and two-level factors).

* Free software: MIT license
* Documentation: https://mldoe.readthedocs.org.